import { decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts } from '@solana/accounts';
import { getProgramDerivedAddress, getAddressEncoder, getAddressDecoder, isProgramDerivedAddress } from '@solana/addresses';
import { getStringEncoder, getBytesEncoder, mapEncoder, getStructEncoder, getArrayEncoder, getU8Encoder, getStructDecoder, getArrayDecoder, getU8Decoder, getBytesDecoder, combineCodec, getU64Encoder, getU64Decoder, getBooleanEncoder, getOptionEncoder, getBooleanDecoder, getOptionDecoder, getScalarEnumEncoder, getScalarEnumDecoder, getDataEnumEncoder, getUnitEncoder, getTupleEncoder, getDataEnumDecoder, getUnitDecoder, getTupleDecoder } from '@solana/codecs';
import { AccountRole, upgradeRoleToSigner } from '@solana/instructions';
import { isTransactionSigner as isTransactionSigner$1 } from '@solana/signers';

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
async function findAuthorityPda(config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({ programAddress, seeds: [] });
}
async function findMintProofPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("mint_proof"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findMintProofV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("mint_proof"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findWhitelistPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [getBytesEncoder({ size: 32 }).encode(seeds.uuid)]
  });
}
async function findWhitelistV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getStringEncoder({ size: "variable" }).encode("whitelist"),
      getAddressEncoder().encode(seeds.namespace),
      getBytesEncoder({ size: 32 }).encode(seeds.uuid)
    ]
  });
}

// src/generated/accounts/authority.ts
function getAuthorityAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["bump", getU8Encoder()],
      ["cosigner", getAddressEncoder()],
      ["owner", getAddressEncoder()],
      ["reserved", getBytesEncoder({ size: 64 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [36, 108, 254, 18, 167, 144, 27, 36]
    })
  );
}
function getAuthorityAccountDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["bump", getU8Decoder()],
    ["cosigner", getAddressDecoder()],
    ["owner", getAddressDecoder()],
    ["reserved", getBytesDecoder({ size: 64 })]
  ]);
}
function getAuthorityAccountDataCodec() {
  return combineCodec(
    getAuthorityAccountDataEncoder(),
    getAuthorityAccountDataDecoder()
  );
}
function decodeAuthority(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getAuthorityAccountDataDecoder()
  );
}
async function fetchAuthority(rpc, address, config) {
  const maybeAccount = await fetchMaybeAuthority(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthority(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeAuthority(maybeAccount);
}
async function fetchAllAuthority(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAuthority(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAuthority(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeAuthority(maybeAccount));
}
function getAuthoritySize() {
  return 137;
}
async function fetchAuthorityFromSeeds(rpc, config = {}) {
  const maybeAccount = await fetchMaybeAuthorityFromSeeds(rpc, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthorityFromSeeds(rpc, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findAuthorityPda({ programAddress });
  return await fetchMaybeAuthority(rpc, address, fetchConfig);
}
function getMintProofAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["proofLen", getU8Encoder()],
      ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }), { size: 28 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [227, 131, 106, 240, 190, 48, 219, 228]
    })
  );
}
function getMintProofAccountDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["proofLen", getU8Decoder()],
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }), { size: 28 })]
  ]);
}
function getMintProofAccountDataCodec() {
  return combineCodec(
    getMintProofAccountDataEncoder(),
    getMintProofAccountDataDecoder()
  );
}
function decodeMintProof(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMintProofAccountDataDecoder()
  );
}
async function fetchMintProof(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProof(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProof(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMintProof(maybeAccount);
}
async function fetchAllMintProof(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProof(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProof(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProof(maybeAccount));
}
function getMintProofSize() {
  return 28;
}
async function fetchMintProofFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofPda(seeds, { programAddress });
  return await fetchMaybeMintProof(rpc, address, fetchConfig);
}
function getMintProofV2AccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["proofLen", getU8Encoder()],
      ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }), { size: 28 })],
      ["creationSlot", getU64Encoder()],
      ["payer", getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: [22, 197, 150, 178, 249, 225, 183, 75]
    })
  );
}
function getMintProofV2AccountDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["proofLen", getU8Decoder()],
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }), { size: 28 })],
    ["creationSlot", getU64Decoder()],
    ["payer", getAddressDecoder()]
  ]);
}
function getMintProofV2AccountDataCodec() {
  return combineCodec(
    getMintProofV2AccountDataEncoder(),
    getMintProofV2AccountDataDecoder()
  );
}
function decodeMintProofV2(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMintProofV2AccountDataDecoder()
  );
}
async function fetchMintProofV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProofV2(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMintProofV2(maybeAccount);
}
async function fetchAllMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProofV2(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProofV2(maybeAccount));
}
function getMintProofV2Size() {
  return 945;
}
async function fetchMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofV2FromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofV2Pda(seeds, { programAddress });
  return await fetchMaybeMintProofV2(rpc, address, fetchConfig);
}
function getWhitelistAccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["version", getU8Encoder()],
      ["bump", getU8Encoder()],
      ["verified", getBooleanEncoder()],
      ["rootHash", getBytesEncoder({ size: 32 })],
      ["uuid", getBytesEncoder({ size: 32 })],
      ["name", getBytesEncoder({ size: 32 })],
      ["frozen", getBooleanEncoder()],
      ["voc", getOptionEncoder(getAddressEncoder())],
      ["fvc", getOptionEncoder(getAddressEncoder())],
      ["reserved", getBytesEncoder({ size: 64 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [204, 176, 52, 79, 146, 121, 54, 247]
    })
  );
}
function getWhitelistAccountDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["version", getU8Decoder()],
    ["bump", getU8Decoder()],
    ["verified", getBooleanDecoder()],
    ["rootHash", getBytesDecoder({ size: 32 })],
    ["uuid", getBytesDecoder({ size: 32 })],
    ["name", getBytesDecoder({ size: 32 })],
    ["frozen", getBooleanDecoder()],
    ["voc", getOptionDecoder(getAddressDecoder())],
    ["fvc", getOptionDecoder(getAddressDecoder())],
    ["reserved", getBytesDecoder({ size: 64 })]
  ]);
}
function getWhitelistAccountDataCodec() {
  return combineCodec(
    getWhitelistAccountDataEncoder(),
    getWhitelistAccountDataDecoder()
  );
}
function decodeWhitelist(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getWhitelistAccountDataDecoder()
  );
}
async function fetchWhitelist(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelist(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelist(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeWhitelist(maybeAccount);
}
async function fetchAllWhitelist(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelist(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelist(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelist(maybeAccount));
}
function getWhitelistSize() {
  return 238;
}
async function fetchWhitelistFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistPda(seeds, { programAddress });
  return await fetchMaybeWhitelist(rpc, address, fetchConfig);
}
function getConditionEncoder() {
  return getStructEncoder([
    ["mode", getModeEncoder()],
    ["value", getAddressEncoder()]
  ]);
}
function getConditionDecoder() {
  return getStructDecoder([
    ["mode", getModeDecoder()],
    ["value", getAddressDecoder()]
  ]);
}
function getConditionCodec() {
  return combineCodec(getConditionEncoder(), getConditionDecoder());
}
function getFullMerkleProofEncoder() {
  return getStructEncoder([
    ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }))],
    ["leaf", getBytesEncoder({ size: 32 })]
  ]);
}
function getFullMerkleProofDecoder() {
  return getStructDecoder([
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }))],
    ["leaf", getBytesDecoder({ size: 32 })]
  ]);
}
function getFullMerkleProofCodec() {
  return combineCodec(getFullMerkleProofEncoder(), getFullMerkleProofDecoder());
}
var Mode2 = /* @__PURE__ */ ((Mode3) => {
  Mode3[Mode3["VOC"] = 0] = "VOC";
  Mode3[Mode3["FVC"] = 1] = "FVC";
  Mode3[Mode3["MerkleTree"] = 2] = "MerkleTree";
  return Mode3;
})(Mode2 || {});
function getModeEncoder() {
  return getScalarEnumEncoder(Mode2);
}
function getModeDecoder() {
  return getScalarEnumDecoder(Mode2);
}
function getModeCodec() {
  return combineCodec(getModeEncoder(), getModeDecoder());
}
function getOperationEncoder() {
  return getDataEnumEncoder([
    ["Noop", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ]
  ]);
}
function getOperationDecoder() {
  return getDataEnumDecoder([
    ["Noop", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ]
  ]);
}
function getOperationCodec() {
  return combineCodec(getOperationEncoder(), getOperationDecoder());
}
function operation(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOperation(kind, value) {
  return value.__kind === kind;
}
var State = /* @__PURE__ */ ((State3) => {
  State3[State3["Unfrozen"] = 0] = "Unfrozen";
  State3[State3["Frozen"] = 1] = "Frozen";
  return State3;
})(State || {});
function getStateEncoder() {
  return getScalarEnumEncoder(State);
}
function getStateDecoder() {
  return getScalarEnumDecoder(State);
}
function getStateCodec() {
  return combineCodec(getStateEncoder(), getStateDecoder());
}

// src/generated/accounts/whitelistV2.ts
function getWhitelistV2AccountDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["version", getU8Encoder()],
      ["bump", getU8Encoder()],
      ["uuid", getBytesEncoder({ size: 32 })],
      ["state", getStateEncoder()],
      ["updateAuthority", getAddressEncoder()],
      ["namespace", getAddressEncoder()],
      ["freezeAuthority", getAddressEncoder()],
      ["conditions", getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: [136, 184, 45, 191, 85, 203, 191, 119]
    })
  );
}
function getWhitelistV2AccountDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["version", getU8Decoder()],
    ["bump", getU8Decoder()],
    ["uuid", getBytesDecoder({ size: 32 })],
    ["state", getStateDecoder()],
    ["updateAuthority", getAddressDecoder()],
    ["namespace", getAddressDecoder()],
    ["freezeAuthority", getAddressDecoder()],
    ["conditions", getArrayDecoder(getConditionDecoder())]
  ]);
}
function getWhitelistV2AccountDataCodec() {
  return combineCodec(
    getWhitelistV2AccountDataEncoder(),
    getWhitelistV2AccountDataDecoder()
  );
}
function decodeWhitelistV2(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getWhitelistV2AccountDataDecoder()
  );
}
async function fetchWhitelistV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelistV2(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeWhitelistV2(maybeAccount);
}
async function fetchAllWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelistV2(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelistV2(maybeAccount));
}
function getWhitelistV2Size() {
  return 239;
}
async function fetchWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistV2Pda(seeds, { programAddress });
  return await fetchMaybeWhitelistV2(rpc, address, fetchConfig);
}

// src/generated/errors/tensorWhitelist.ts
var TensorWhitelistProgramErrorCode = /* @__PURE__ */ ((TensorWhitelistProgramErrorCode3) => {
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["BAD_COSIGNER"] = 6e3] = "BAD_COSIGNER";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["MISSING_VERIFICATION"] = 6001] = "MISSING_VERIFICATION";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["MISSING_NAME"] = 6002] = "MISSING_NAME";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["BAD_WHITELIST"] = 6003] = "BAD_WHITELIST";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["PROOF_TOO_LONG"] = 6004] = "PROOF_TOO_LONG";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["BAD_OWNER"] = 6005] = "BAD_OWNER";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["FAILED_VOC_VERIFICATION"] = 6006] = "FAILED_VOC_VERIFICATION";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["FAILED_FVC_VERIFICATION"] = 6007] = "FAILED_FVC_VERIFICATION";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["FAILED_MERKLE_PROOF_VERIFICATION"] = 6008] = "FAILED_MERKLE_PROOF_VERIFICATION";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["NO_CONDITIONS"] = 6009] = "NO_CONDITIONS";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["INVALID_AUTHORITY"] = 6010] = "INVALID_AUTHORITY";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["NOT_MERKLE_ROOT"] = 6011] = "NOT_MERKLE_ROOT";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["INVALID_WHITELIST_INDEX"] = 6012] = "INVALID_WHITELIST_INDEX";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["TOO_MANY_CONDITIONS"] = 6013] = "TOO_MANY_CONDITIONS";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["EMPTY_CONDITIONS"] = 6014] = "EMPTY_CONDITIONS";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["TOO_MANY_MERKLE_PROOFS"] = 6015] = "TOO_MANY_MERKLE_PROOFS";
  TensorWhitelistProgramErrorCode3[TensorWhitelistProgramErrorCode3["WHITELIST_IS_FROZEN"] = 6016] = "WHITELIST_IS_FROZEN";
  return TensorWhitelistProgramErrorCode3;
})(TensorWhitelistProgramErrorCode || {});
var TensorWhitelistProgramError = class extends Error {
  name = "TensorWhitelistProgramError";
  code;
  cause;
  constructor(code, name, message, cause) {
    super(`${name} (${code}): ${message}`);
    this.code = code;
    this.cause = cause;
  }
};
var tensorWhitelistProgramErrorCodeMap;
if (__DEV__) {
  tensorWhitelistProgramErrorCodeMap = {
    [6e3 /* BAD_COSIGNER */]: [
      "BadCosigner",
      `passed in cosigner doesnt have the rights to do this`
    ],
    [6001 /* MISSING_VERIFICATION */]: [
      "MissingVerification",
      `missing all 3 verification methods: at least one must be present`
    ],
    [6002 /* MISSING_NAME */]: [
      "MissingName",
      `missing name`
    ],
    [6003 /* BAD_WHITELIST */]: [
      "BadWhitelist",
      `bad whitelist`
    ],
    [6004 /* PROOF_TOO_LONG */]: [
      "ProofTooLong",
      `proof provided exceeds the limit of 32 hashes`
    ],
    [6005 /* BAD_OWNER */]: [
      "BadOwner",
      `passed in owner doesnt have the rights to do this`
    ],
    [6006 /* FAILED_VOC_VERIFICATION */]: [
      "FailedVocVerification",
      `failed voc verification`
    ],
    [6007 /* FAILED_FVC_VERIFICATION */]: [
      "FailedFvcVerification",
      `failed fvc verification`
    ],
    [6008 /* FAILED_MERKLE_PROOF_VERIFICATION */]: [
      "FailedMerkleProofVerification",
      `failed merkle proof verification`
    ],
    [6009 /* NO_CONDITIONS */]: [
      "NoConditions",
      `no whitelist conditions provided`
    ],
    [6010 /* INVALID_AUTHORITY */]: [
      "InvalidAuthority",
      `invalid authority`
    ],
    [6011 /* NOT_MERKLE_ROOT */]: [
      "NotMerkleRoot",
      `condition at index not a merkle root`
    ],
    [6012 /* INVALID_WHITELIST_INDEX */]: [
      "InvalidWhitelistIndex",
      `invalid whitelist index`
    ],
    [6013 /* TOO_MANY_CONDITIONS */]: [
      "TooManyConditions",
      `too many conditions`
    ],
    [6014 /* EMPTY_CONDITIONS */]: [
      "EmptyConditions",
      `cannot have empty conditions`
    ],
    [6015 /* TOO_MANY_MERKLE_PROOFS */]: [
      "TooManyMerkleProofs",
      `too many merkle proofs`
    ],
    [6016 /* WHITELIST_IS_FROZEN */]: [
      "WhitelistIsFrozen",
      `whitelist is frozen`
    ]
  };
}
function getTensorWhitelistProgramErrorFromCode(code, cause) {
  if (__DEV__) {
    return new TensorWhitelistProgramError(
      code,
      ...tensorWhitelistProgramErrorCodeMap[code],
      cause
    );
  }
  return new TensorWhitelistProgramError(
    code,
    "Unknown",
    "Error message not available in production bundles. Compile with __DEV__ set to true to see more information.",
    cause
  );
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectProgramDerivedAddress(value) {
  if (!value || !Array.isArray(value) || !isProgramDerivedAddress(value)) {
    throw new Error("Expected a ProgramDerivedAddress.");
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      if (optionalAccountStrategy === "omitted")
        return;
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}
function memcmp(data, bytes, offset) {
  const slice = data.slice(offset, offset + bytes.length);
  if (slice.length !== bytes.length)
    return false;
  return bytes.every((b, i) => b === slice[i]);
}

// src/generated/programs/tensorWhitelist.ts
var TENSOR_WHITELIST_PROGRAM_ADDRESS = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW";
function getTensorWhitelistProgram() {
  return {
    name: "tensorWhitelist",
    address: TENSOR_WHITELIST_PROGRAM_ADDRESS,
    getErrorFromCode(code, cause) {
      return getTensorWhitelistProgramErrorFromCode(code, cause);
    }
  };
}
var TensorWhitelistAccount = /* @__PURE__ */ ((TensorWhitelistAccount2) => {
  TensorWhitelistAccount2[TensorWhitelistAccount2["Authority"] = 0] = "Authority";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProofV2"] = 1] = "MintProofV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProof"] = 2] = "MintProof";
  TensorWhitelistAccount2[TensorWhitelistAccount2["WhitelistV2"] = 3] = "WhitelistV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["Whitelist"] = 4] = "Whitelist";
  return TensorWhitelistAccount2;
})(TensorWhitelistAccount || {});
function identifyTensorWhitelistAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (memcmp(data, new Uint8Array([36, 108, 254, 18, 167, 144, 27, 36]), 0)) {
    return 0 /* Authority */;
  }
  if (memcmp(data, new Uint8Array([22, 197, 150, 178, 249, 225, 183, 75]), 0)) {
    return 1 /* MintProofV2 */;
  }
  if (memcmp(data, new Uint8Array([227, 131, 106, 240, 190, 48, 219, 228]), 0)) {
    return 2 /* MintProof */;
  }
  if (memcmp(data, new Uint8Array([136, 184, 45, 191, 85, 203, 191, 119]), 0)) {
    return 3 /* WhitelistV2 */;
  }
  if (memcmp(data, new Uint8Array([204, 176, 52, 79, 146, 121, 54, 247]), 0)) {
    return 4 /* Whitelist */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorWhitelist account."
  );
}
var TensorWhitelistInstruction = /* @__PURE__ */ ((TensorWhitelistInstruction2) => {
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelist"] = 0] = "FreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateAuthority"] = 1] = "InitUpdateAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateMintProof"] = 2] = "InitUpdateMintProof";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateWhitelist"] = 3] = "InitUpdateWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocAuthority"] = 4] = "ReallocAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocWhitelist"] = 5] = "ReallocWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelist"] = 6] = "UnfreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CreateWhitelistV2"] = 7] = "CreateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UpdateWhitelistV2"] = 8] = "UpdateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CreateMintProofV2"] = 9] = "CreateMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CloseMintProofV2"] = 10] = "CloseMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelistV2"] = 11] = "FreezeWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelistV2"] = 12] = "UnfreezeWhitelistV2";
  return TensorWhitelistInstruction2;
})(TensorWhitelistInstruction || {});
function identifyTensorWhitelistInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (memcmp(data, new Uint8Array([248, 112, 12, 150, 175, 238, 38, 184]), 0)) {
    return 0 /* FreezeWhitelist */;
  }
  if (memcmp(data, new Uint8Array([53, 144, 79, 150, 196, 110, 22, 55]), 0)) {
    return 1 /* InitUpdateAuthority */;
  }
  if (memcmp(data, new Uint8Array([30, 77, 123, 9, 191, 37, 52, 159]), 0)) {
    return 2 /* InitUpdateMintProof */;
  }
  if (memcmp(data, new Uint8Array([255, 1, 192, 134, 111, 49, 212, 131]), 0)) {
    return 3 /* InitUpdateWhitelist */;
  }
  if (memcmp(data, new Uint8Array([128, 120, 16, 197, 85, 34, 2, 91]), 0)) {
    return 4 /* ReallocAuthority */;
  }
  if (memcmp(data, new Uint8Array([173, 147, 168, 152, 181, 46, 55, 60]), 0)) {
    return 5 /* ReallocWhitelist */;
  }
  if (memcmp(data, new Uint8Array([215, 119, 9, 92, 160, 139, 226, 253]), 0)) {
    return 6 /* UnfreezeWhitelist */;
  }
  if (memcmp(data, new Uint8Array([31, 207, 213, 77, 105, 13, 127, 98]), 0)) {
    return 7 /* CreateWhitelistV2 */;
  }
  if (memcmp(data, new Uint8Array([184, 188, 157, 214, 205, 49, 74, 226]), 0)) {
    return 8 /* UpdateWhitelistV2 */;
  }
  if (memcmp(data, new Uint8Array([219, 176, 21, 37, 145, 89, 154, 53]), 0)) {
    return 9 /* CreateMintProofV2 */;
  }
  if (memcmp(data, new Uint8Array([237, 78, 8, 208, 47, 148, 145, 170]), 0)) {
    return 10 /* CloseMintProofV2 */;
  }
  if (memcmp(data, new Uint8Array([69, 158, 243, 78, 116, 68, 221, 113]), 0)) {
    return 11 /* FreezeWhitelistV2 */;
  }
  if (memcmp(data, new Uint8Array([51, 105, 214, 84, 252, 188, 26, 1]), 0)) {
    return 12 /* UnfreezeWhitelistV2 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorWhitelist instruction."
  );
}

// src/generated/instructions/closeMintProofV2.ts
function getCloseMintProofV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [237, 78, 8, 208, 47, 148, 145, 170]
    })
  );
}
function getCloseMintProofV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getCloseMintProofV2InstructionDataCodec() {
  return combineCodec(
    getCloseMintProofV2InstructionDataEncoder(),
    getCloseMintProofV2InstructionDataDecoder()
  );
}
function getCloseMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCloseMintProofV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      signer: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCloseMintProofV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateMintProofV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }))]
    ]),
    (value) => ({
      ...value,
      discriminator: [219, 176, 21, 37, 145, 89, 154, 53]
    })
  );
}
function getCreateMintProofV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }))]
  ]);
}
function getCreateMintProofV2InstructionDataCodec() {
  return combineCodec(
    getCreateMintProofV2InstructionDataEncoder(),
    getCreateMintProofV2InstructionDataDecoder()
  );
}
async function getCreateMintProofV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofPda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreateMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      mint: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateMintProofV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateWhitelistV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["uuid", getBytesEncoder({ size: 32 })],
      ["freezeAuthority", getOptionEncoder(getAddressEncoder())],
      ["conditions", getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: [31, 207, 213, 77, 105, 13, 127, 98]
    })
  );
}
function getCreateWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["uuid", getBytesDecoder({ size: 32 })],
    ["freezeAuthority", getOptionDecoder(getAddressDecoder())],
    ["conditions", getArrayDecoder(getConditionDecoder())]
  ]);
}
function getCreateWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getCreateWhitelistV2InstructionDataEncoder(),
    getCreateWhitelistV2InstructionDataDecoder()
  );
}
async function getCreateWhitelistV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistPda({
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      namespace: getNextAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [248, 112, 12, 150, 175, 238, 38, 184]
    })
  );
}
function getFreezeWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getFreezeWhitelistInstructionDataCodec() {
  return combineCodec(
    getFreezeWhitelistInstructionDataEncoder(),
    getFreezeWhitelistInstructionDataDecoder()
  );
}
async function getFreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getFreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getFreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [69, 158, 243, 78, 116, 68, 221, 113]
    })
  );
}
function getFreezeWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getFreezeWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getFreezeWhitelistV2InstructionDataEncoder(),
    getFreezeWhitelistV2InstructionDataDecoder()
  );
}
function getFreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getFreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getFreezeWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getInitUpdateAuthorityInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["newCosigner", getOptionEncoder(getAddressEncoder())],
      ["newOwner", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: [53, 144, 79, 150, 196, 110, 22, 55]
    })
  );
}
function getInitUpdateAuthorityInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["newCosigner", getOptionDecoder(getAddressDecoder())],
    ["newOwner", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getInitUpdateAuthorityInstructionDataCodec() {
  return combineCodec(
    getInitUpdateAuthorityInstructionDataEncoder(),
    getInitUpdateAuthorityInstructionDataDecoder()
  );
}
async function getInitUpdateAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateMintProofInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["proof", getArrayEncoder(getBytesEncoder({ size: 32 }))]
    ]),
    (value) => ({ ...value, discriminator: [30, 77, 123, 9, 191, 37, 52, 159] })
  );
}
function getInitUpdateMintProofInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["proof", getArrayDecoder(getBytesDecoder({ size: 32 }))]
  ]);
}
function getInitUpdateMintProofInstructionDataCodec() {
  return combineCodec(
    getInitUpdateMintProofInstructionDataEncoder(),
    getInitUpdateMintProofInstructionDataDecoder()
  );
}
async function getInitUpdateMintProofInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofPda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateMintProofInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateMintProofInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      mint: getNextAccount(),
      mintProof: getNextAccount(),
      user: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateMintProofInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateWhitelistInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["uuid", getBytesEncoder({ size: 32 })],
      ["rootHash", getOptionEncoder(getBytesEncoder({ size: 32 }))],
      ["name", getOptionEncoder(getBytesEncoder({ size: 32 }))],
      ["voc", getOptionEncoder(getAddressEncoder())],
      ["fvc", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: [255, 1, 192, 134, 111, 49, 212, 131]
    })
  );
}
function getInitUpdateWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["uuid", getBytesDecoder({ size: 32 })],
    ["rootHash", getOptionDecoder(getBytesDecoder({ size: 32 }))],
    ["name", getOptionDecoder(getBytesDecoder({ size: 32 }))],
    ["voc", getOptionDecoder(getAddressDecoder())],
    ["fvc", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getInitUpdateWhitelistInstructionDataCodec() {
  return combineCodec(
    getInitUpdateWhitelistInstructionDataEncoder(),
    getInitUpdateWhitelistInstructionDataDecoder()
  );
}
async function getInitUpdateWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistPda({
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateWhitelistInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getReallocAuthorityInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({ ...value, discriminator: [128, 120, 16, 197, 85, 34, 2, 91] })
  );
}
function getReallocAuthorityInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getReallocAuthorityInstructionDataCodec() {
  return combineCodec(
    getReallocAuthorityInstructionDataEncoder(),
    getReallocAuthorityInstructionDataDecoder()
  );
}
async function getReallocAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocAuthorityInstructionDataDecoder().decode(instruction.data)
  };
}
function getReallocWhitelistInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [173, 147, 168, 152, 181, 46, 55, 60]
    })
  );
}
function getReallocWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getReallocWhitelistInstructionDataCodec() {
  return combineCodec(
    getReallocWhitelistInstructionDataEncoder(),
    getReallocWhitelistInstructionDataDecoder()
  );
}
async function getReallocWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistInstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [215, 119, 9, 92, 160, 139, 226, 253]
    })
  );
}
function getUnfreezeWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getUnfreezeWhitelistInstructionDataCodec() {
  return combineCodec(
    getUnfreezeWhitelistInstructionDataEncoder(),
    getUnfreezeWhitelistInstructionDataDecoder()
  );
}
async function getUnfreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getUnfreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUnfreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })]
    ]),
    (value) => ({
      ...value,
      discriminator: [51, 105, 214, 84, 252, 188, 26, 1]
    })
  );
}
function getUnfreezeWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })]
  ]);
}
function getUnfreezeWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getUnfreezeWhitelistV2InstructionDataEncoder(),
    getUnfreezeWhitelistV2InstructionDataDecoder()
  );
}
function getUnfreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getUnfreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getUnfreezeWhitelistV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUpdateWhitelistV2InstructionDataEncoder() {
  return mapEncoder(
    getStructEncoder([
      ["discriminator", getArrayEncoder(getU8Encoder(), { size: 8 })],
      ["freezeAuthority", getOperationEncoder()],
      ["conditions", getOptionEncoder(getArrayEncoder(getConditionEncoder()))]
    ]),
    (value) => ({
      ...value,
      discriminator: [184, 188, 157, 214, 205, 49, 74, 226]
    })
  );
}
function getUpdateWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getArrayDecoder(getU8Decoder(), { size: 8 })],
    ["freezeAuthority", getOperationDecoder()],
    ["conditions", getOptionDecoder(getArrayDecoder(getConditionDecoder()))]
  ]);
}
function getUpdateWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getUpdateWhitelistV2InstructionDataEncoder(),
    getUpdateWhitelistV2InstructionDataDecoder()
  );
}
function getUpdateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    newUpdateAuthority: {
      value: input.newUpdateAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.newUpdateAuthority),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUpdateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_WHITELIST_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      newUpdateAuthority: getNextOptionalAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUpdateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}

// src/plugin.ts
var tensorWhitelist = () => ({
  install() {
  }
});

export { Mode2 as Mode, State, TENSOR_WHITELIST_PROGRAM_ADDRESS, TensorWhitelistAccount, TensorWhitelistInstruction, TensorWhitelistProgramError, TensorWhitelistProgramErrorCode, decodeAuthority, decodeMintProof, decodeMintProofV2, decodeWhitelist, decodeWhitelistV2, expectAddress, expectProgramDerivedAddress, expectSome, expectTransactionSigner, fetchAllAuthority, fetchAllMaybeAuthority, fetchAllMaybeMintProof, fetchAllMaybeMintProofV2, fetchAllMaybeWhitelist, fetchAllMaybeWhitelistV2, fetchAllMintProof, fetchAllMintProofV2, fetchAllWhitelist, fetchAllWhitelistV2, fetchAuthority, fetchAuthorityFromSeeds, fetchMaybeAuthority, fetchMaybeAuthorityFromSeeds, fetchMaybeMintProof, fetchMaybeMintProofFromSeeds, fetchMaybeMintProofV2, fetchMaybeMintProofV2FromSeeds, fetchMaybeWhitelist, fetchMaybeWhitelistFromSeeds, fetchMaybeWhitelistV2, fetchMaybeWhitelistV2FromSeeds, fetchMintProof, fetchMintProofFromSeeds, fetchMintProofV2, fetchMintProofV2FromSeeds, fetchWhitelist, fetchWhitelistFromSeeds, fetchWhitelistV2, fetchWhitelistV2FromSeeds, findAuthorityPda, findMintProofPda, findMintProofV2Pda, findWhitelistPda, findWhitelistV2Pda, getAccountMetaFactory, getAuthorityAccountDataCodec, getAuthorityAccountDataDecoder, getAuthorityAccountDataEncoder, getAuthoritySize, getCloseMintProofV2Instruction, getCloseMintProofV2InstructionDataCodec, getCloseMintProofV2InstructionDataDecoder, getCloseMintProofV2InstructionDataEncoder, getConditionCodec, getConditionDecoder, getConditionEncoder, getCreateMintProofV2Instruction, getCreateMintProofV2InstructionAsync, getCreateMintProofV2InstructionDataCodec, getCreateMintProofV2InstructionDataDecoder, getCreateMintProofV2InstructionDataEncoder, getCreateWhitelistV2Instruction, getCreateWhitelistV2InstructionAsync, getCreateWhitelistV2InstructionDataCodec, getCreateWhitelistV2InstructionDataDecoder, getCreateWhitelistV2InstructionDataEncoder, getFreezeWhitelistInstruction, getFreezeWhitelistInstructionAsync, getFreezeWhitelistInstructionDataCodec, getFreezeWhitelistInstructionDataDecoder, getFreezeWhitelistInstructionDataEncoder, getFreezeWhitelistV2Instruction, getFreezeWhitelistV2InstructionDataCodec, getFreezeWhitelistV2InstructionDataDecoder, getFreezeWhitelistV2InstructionDataEncoder, getFullMerkleProofCodec, getFullMerkleProofDecoder, getFullMerkleProofEncoder, getInitUpdateAuthorityInstruction, getInitUpdateAuthorityInstructionAsync, getInitUpdateAuthorityInstructionDataCodec, getInitUpdateAuthorityInstructionDataDecoder, getInitUpdateAuthorityInstructionDataEncoder, getInitUpdateMintProofInstruction, getInitUpdateMintProofInstructionAsync, getInitUpdateMintProofInstructionDataCodec, getInitUpdateMintProofInstructionDataDecoder, getInitUpdateMintProofInstructionDataEncoder, getInitUpdateWhitelistInstruction, getInitUpdateWhitelistInstructionAsync, getInitUpdateWhitelistInstructionDataCodec, getInitUpdateWhitelistInstructionDataDecoder, getInitUpdateWhitelistInstructionDataEncoder, getMintProofAccountDataCodec, getMintProofAccountDataDecoder, getMintProofAccountDataEncoder, getMintProofSize, getMintProofV2AccountDataCodec, getMintProofV2AccountDataDecoder, getMintProofV2AccountDataEncoder, getMintProofV2Size, getModeCodec, getModeDecoder, getModeEncoder, getOperationCodec, getOperationDecoder, getOperationEncoder, getReallocAuthorityInstruction, getReallocAuthorityInstructionAsync, getReallocAuthorityInstructionDataCodec, getReallocAuthorityInstructionDataDecoder, getReallocAuthorityInstructionDataEncoder, getReallocWhitelistInstruction, getReallocWhitelistInstructionAsync, getReallocWhitelistInstructionDataCodec, getReallocWhitelistInstructionDataDecoder, getReallocWhitelistInstructionDataEncoder, getStateCodec, getStateDecoder, getStateEncoder, getTensorWhitelistProgram, getTensorWhitelistProgramErrorFromCode, getUnfreezeWhitelistInstruction, getUnfreezeWhitelistInstructionAsync, getUnfreezeWhitelistInstructionDataCodec, getUnfreezeWhitelistInstructionDataDecoder, getUnfreezeWhitelistInstructionDataEncoder, getUnfreezeWhitelistV2Instruction, getUnfreezeWhitelistV2InstructionDataCodec, getUnfreezeWhitelistV2InstructionDataDecoder, getUnfreezeWhitelistV2InstructionDataEncoder, getUpdateWhitelistV2Instruction, getUpdateWhitelistV2InstructionDataCodec, getUpdateWhitelistV2InstructionDataDecoder, getUpdateWhitelistV2InstructionDataEncoder, getWhitelistAccountDataCodec, getWhitelistAccountDataDecoder, getWhitelistAccountDataEncoder, getWhitelistSize, getWhitelistV2AccountDataCodec, getWhitelistV2AccountDataDecoder, getWhitelistV2AccountDataEncoder, getWhitelistV2Size, identifyTensorWhitelistAccount, identifyTensorWhitelistInstruction, isOperation, isTransactionSigner, memcmp, operation, parseCloseMintProofV2Instruction, parseCreateMintProofV2Instruction, parseCreateWhitelistV2Instruction, parseFreezeWhitelistInstruction, parseFreezeWhitelistV2Instruction, parseInitUpdateAuthorityInstruction, parseInitUpdateMintProofInstruction, parseInitUpdateWhitelistInstruction, parseReallocAuthorityInstruction, parseReallocWhitelistInstruction, parseUnfreezeWhitelistInstruction, parseUnfreezeWhitelistV2Instruction, parseUpdateWhitelistV2Instruction, tensorWhitelist };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map